==> smart-components-0.0.34.tgz: package/lib/top/Top.js <==
'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

require('./top.scss');

var _TopRight = require('./TopRight.js');

var _TopRight2 = _interopRequireDefault(_TopRight);

var _componentCookie = require('component-cookie');

var _componentCookie2 = _interopRequireDefault(_componentCookie);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-enable */

/**********************************************
 * created by zhangbaige on 2016年4月26日
 * email: zhangbaige@innobuddy.com
 * 顶部模块
 **********************************************/
/* eslint-disable */
var Top = _react2.default.createClass({
  displayName: 'Top',

  propTypes: function propTypes() {
    return {
      cdnCommon: _react2.default.PropTypes.string,
      smartUrl: _react2.default.PropTypes.string,
      kaoweiUrl: _react2.default.PropTypes.string,
      schoolUrl: _react2.default.PropTypes.string,
      infoUrl: _react2.default.PropTypes.string,
      vipChain: _react2.default.PropTypes.string,
      openSignIn: _react2.default.PropTypes.func,
      userCenterApi: _react2.default.PropTypes.string,
      initToken: _react2.default.PropTypes.string,
      group: _react2.default.PropTypes.string,
      from: _react2.default.PropTypes.string
    };
  },

  getDefaultProps: function getDefaultProps() {
    return {
      cdnCommon: 'http://media8.smartstudy.com',
      smartUrl: 'http://www.smartstudy.com',
      kaoweiUrl: 'http://app.smartstudy.com/kaowei',
      schoolUrl: 'http://www.beikaodi.com/school',
      infoUrl: 'http://info.smartstudy.com',
      vipChain: 'http://vip.smartstudy.com/merchant',
      openSignIn: function openSignIn() {
        console.log('打开登录弹框');
      },
      userCenterApi: '',
      initToken: 'N0LXYPFL03O4TU2WQEU536NDJR7IJKII',
      group: 'C',
      from: 'pc'
    };
  },

  componentDidMount: function componentDidMount() {
    var ss_user = (0, _componentCookie2.default)('ss_user');
    if (ss_user) {
      var ss_userObj = JSON.parse(ss_user);
      this.setState({
        name: ss_userObj.name,
        uid: ss_userObj.id
      });
    }
  },

  getInitialState: function getInitialState() {
    return {
      name: '',
      uid: ''
    };
  },

  render: function render() {

    return _react2.default.createElement(
      'div',
      { className: 's-top' },
      _react2.default.createElement(
        'div',
        { className: 'top-content' },
        _react2.default.createElement(
          'div',
          { className: 'top-left' },
          _react2.default.createElement(
            'a',
            { href: this.props.kaoweiUrl, target: '_blank' },
            '托福抢考位'
          ),
          _react2.default.createElement(
            'a',
            { href: this.props.schoolUrl, target: '_blank' },
            '美国院校库'
          ),
          _react2.default.createElement(
            'a',
            { href: this.props.infoUrl, target: '_blank' },
            '资料下载'
          ),
          this.state.uid ? _react2.default.createElement(
            'a',
            { href: this.props.smartUrl + '/user/card/3', target: '_blank' },
            '课程卡激活'
          ) : _react2.default.createElement(
            'a',
            { href: 'javascript:;', onClick: this.courseCard },
            '课程卡激活'
          ),
          _react2.default.createElement(
            'a',
            { href: this.props.vipChain, target: '_blank' },
            '招商加盟'
          )
        ),
        _react2.default.createElement(_TopRight2.default, {
          smartUrl: this.props.smartUrl,
          userCenterApi: this.props.userCenterApi,
          group: this.props.group,
          from: this.props.from,
          initToken: this.props.initToken
        }),
        _react2.default.createElement(
          'div',
          { className: 'slogan' },
          _react2.default.createElement('img', { width: '200', height: '36', src: this.props.cdnCommon + '/common/images/slogan.png' })
        )
      )
    );
  },

  courseCard: function courseCard() {
    this.props.openSignIn();
  }
});
module.exports = Top;

==> smart-components-0.0.42.tgz: package/lib/top/Top.js <==
'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

require('./top.scss');

var _TopRight = require('./TopRight.js');

var _TopRight2 = _interopRequireDefault(_TopRight);

var _componentCookie = require('component-cookie');

var _componentCookie2 = _interopRequireDefault(_componentCookie);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-enable */

/**********************************************
 * created by zhangbaige on 2016年4月26日
 * email: zhangbaige@innobuddy.com
 * 顶部模块
 **********************************************/
/* eslint-disable */
var Top = _react2.default.createClass({
  displayName: 'Top',

  propTypes: function propTypes() {
    return {
      cdnCommon: _react2.default.PropTypes.string,
      smartUrl: _react2.default.PropTypes.string,
      kaoweiUrl: _react2.default.PropTypes.string,
      schoolUrl: _react2.default.PropTypes.string,
      infoUrl: _react2.default.PropTypes.string,
      vipChain: _react2.default.PropTypes.string,
      openSignIn: _react2.default.PropTypes.func,
      userCenterApi: _react2.default.PropTypes.string,
      initToken: _react2.default.PropTypes.string,
      group: _react2.default.PropTypes.string,
      from: _react2.default.PropTypes.string
    };
  },

  getDefaultProps: function getDefaultProps() {
    return {
      cdnCommon: 'http://media8.smartstudy.com',
      smartUrl: 'http://www.smartstudy.com',
      kaoweiUrl: 'http://app.smartstudy.com/kaowei',
      schoolUrl: 'http://www.beikaodi.com/school',
      infoUrl: 'http://beikao.smartstudy.com/',
      vipChain: 'http://vip.smartstudy.com/merchant',
      openSignIn: function openSignIn() {
        console.log('打开登录弹框');
      },
      userCenterApi: '',
      initToken: 'N0LXYPFL03O4TU2WQEU536NDJR7IJKII',
      group: 'C',
      from: 'pc'
    };
  },

  componentDidMount: function componentDidMount() {
    var ss_user = (0, _componentCookie2.default)('ss_user');
    if (ss_user) {
      var ss_userObj = JSON.parse(ss_user);
      this.setState({
        name: ss_userObj.name,
        uid: ss_userObj.id
      });
    }
  },

  getInitialState: function getInitialState() {
    return {
      name: '',
      uid: ''
    };
  },

  render: function render() {

    return _react2.default.createElement(
      'div',
      { className: 's-top' },
      _react2.default.createElement(
        'div',
        { className: 'top-content' },
        _react2.default.createElement(
          'div',
          { className: 'top-left' },
          _react2.default.createElement(
            'a',
            { href: this.props.kaoweiUrl, target: '_blank' },
            '托福抢考位'
          ),
          _react2.default.createElement(
            'a',
            { href: this.props.schoolUrl, target: '_blank' },
            '美国院校库'
          ),
          _react2.default.createElement(
            'a',
            { href: this.props.infoUrl, target: '_blank' },
            '备考资料'
          ),
          this.state.uid ? _react2.default.createElement(
            'a',
            { href: this.props.smartUrl + '/user/card/3', target: '_blank' },
            '课程卡激活'
          ) : _react2.default.createElement(
            'a',
            { href: 'javascript:;', onClick: this.courseCard },
            '课程卡激活'
          ),
          _react2.default.createElement(
            'a',
            { href: this.props.vipChain, target: '_blank' },
            '招商加盟'
          )
        ),
        _react2.default.createElement(_TopRight2.default, {
          smartUrl: this.props.smartUrl,
          userCenterApi: this.props.userCenterApi,
          group: this.props.group,
          from: this.props.from,
          initToken: this.props.initToken
        }),
        _react2.default.createElement(
          'div',
          { className: 'slogan' },
          _react2.default.createElement('img', { width: '200', height: '36', src: this.props.cdnCommon + '/common/images/slogan.png' })
        )
      )
    );
  },

  courseCard: function courseCard() {
    this.props.openSignIn();
  }
});
module.exports = Top;
